@@ -267,7 +267,7 @@ def plot_GP(gp_regressor: GaussianProcessRegressor,
 def plot_selection_frequency(
     dataframe: pd.DataFrame,
     bins: int = 10,
-    val_range: Optional[Tuple[float, float]] = None,
+    val_range: Optional[Tuple[float, float]] = (0.0, 500.0),
     column_names_specified: Optional[str] = None,
     figure_size: Tuple[int, int] = (10,5), 
     mode: str = 'sum'
@@ -305,7 +305,7 @@ def plot_selection_frequency(
     if column_names_specified is not None:
         print(f"The columns included in dataframe: {list(dataframe.columns)}.")
 
-        x_data_points = dataframe[column_names_specified].to_numpy()
+        target_data_points = dataframe[column_names_specified].to_numpy()
         
         '''
         n_names_specified = len(column_names_specified)
@@ -332,7 +332,7 @@ def plot_selection_frequency(
             z_data_points = dataframe[z_column_name].tolist()
         '''
     else:
-        target_data_points = dataframe.iloc[:, 1].to_numpy()
+        target_data_points = dataframe.iloc[:, 0].to_numpy()
         '''
         y_data_points = dataframe.iloc[:, 1].tolist()
         '''
@@ -346,11 +346,14 @@ def plot_selection_frequency(
         target_data_points=target_data_points[mask_idx]
 
     hist, dv1_pos=np.histogram(target_data_points, bins=bins)
-    
+    print(dv1_pos)
     if mode=='average':
         hist=hist/len(target_data_points)    ## Determining the width of each bar in the figure.
 
-    bin_width = (val_range[1] - val_range[0]) / bins if val_range is not None else dv1_pos[1] - dv1_pos[0]
+    if val_range is not None:
+        bin_width = (val_range[1] - val_range[0])/bins
+    else:
+        bin_width = (dv1_pos[-1] - dv1_pos[0])/bins
 
     bin_centers = dv1_pos[:-1] + bin_width / 2
     
